
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.6.5',
    'branch_nick': '(no',
    'revision_id': '8442c6747fccd65f6a14c83124da301284778d83',
    'revno': 4111
}
